@@ -5,20 +5,20 @@ stat_four_gamete_class <- R6Class("stat_four_gamete", inherit = sumstat_class,
     req_segsites = TRUE
   ),
   public = list(
-    initialize = function(name, population, transformation) {
+    initialize = function(name, population, transformation, na.rm=FALSE) {
       assert_that(identical(population, "all") || is.numeric(population))
       assert_that(length(population) == 1)
       private$population <- population
       super$initialize(name, transformation)
     },
-    calculate = function(seg_sites, trees, files, model, sim_tasks = NULL) {
+    calculate = function(seg_sites, trees, files, model, sim_tasks = NULL, na.rm=FALSE) {
       individuals <- get_population_individuals(model, private$population,
                                                 haploids = !is_unphased(model))
       calc_four_gamete_stat(seg_sites,
                             individuals,
                             get_locus_length_matrix(model),
                             ifelse(is_unphased(model),
-                                   get_samples_per_ind(model), 1))
+                                   get_samples_per_ind(model), 1), na.rm)
     }
   )
 )
@@ -43,10 +43,11 @@ stat_four_gamete_class <- R6Class("stat_four_gamete", inherit = sumstat_class,
 #'   the value of the statistics are written to an entry of the returned list
 #'   with this name. Summary statistic names must be unique in a model.
 #' @param population The population for which the statistic is calculated.
-#'   Can also be "all" to calculate it from all populations.
+#'   Can also be "all" to calculate it from all populations. Default is population 1.
 #' @param transformation An optional function for transforming the results
 #'   of the statistic. If specified, the results of the transformation are
 #'   returned instead of the original values.
+#' @param na.rm should missing data be ignored? Default is FALSE.
 #' @return
 #'   The statistic generates a matrix where each row represents one locus, and
 #'   the columns give the statistic for different classes of pairs of SNPs:
@@ -76,6 +77,6 @@ stat_four_gamete_class <- R6Class("stat_four_gamete", inherit = sumstat_class,
 #' stats <- simulate(model)
 #' print(stats$four_gamete)
 sumstat_four_gamete  <- function(name = "four_gamete", population = 1,
-                                 transformation = identity) {
-  stat_four_gamete_class$new(name, population, transformation)
+                                 transformation = identity, na.rm=FALSE) {
+  stat_four_gamete_class$new(name, population, transformation, na.rm)
 }
